"""Core loaders — MCP tools, agents, and skills.

Public API::

    from octo.core.loaders.agent_loader import AgentConfig, load_agents, load_octo_agents
    from octo.core.loaders.skill_loader import SkillConfig, load_skills
    from octo.core.loaders.mcp_loader import MCPSessionPool, create_mcp_client
"""
from __future__ import annotations
